summaryrefslogtreecommitdiff
path: root/ace/ARGV.h
diff options
context:
space:
mode:
authorbrunsch <brunsch@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>2000-04-23 04:43:59 +0000
committerbrunsch <brunsch@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>2000-04-23 04:43:59 +0000
commita7c03cabf931b077d70c6f80ec02c7728a429f49 (patch)
tree61d38d262d43ac77fc2ad94c9e7e850cd5607622 /ace/ARGV.h
parent2aa7b10780ad7c670f588dce4ec341351a0646aa (diff)
downloadATCD-a7c03cabf931b077d70c6f80ec02c7728a429f49.tar.gz
ChangeLogTag:Sat Apr 22 20:53:11 2000 Darrell Brunsch <brunsch@uci.edu>
Diffstat (limited to 'ace/ARGV.h')
-rw-r--r--ace/ARGV.h36
1 files changed, 18 insertions, 18 deletions
diff --git a/ace/ARGV.h b/ace/ARGV.h
index 5585a5150f9..233c818c3b5 100644
--- a/ace/ARGV.h
+++ b/ace/ARGV.h
@@ -34,7 +34,7 @@ class ACE_Export ACE_ARGV
// environment variable substitutions if necessary.
public:
// = Initialization and termination.
- ACE_ARGV (const ASYS_TCHAR buf[],
+ ACE_ARGV (const ACE_TCHAR buf[],
int substitute_env_args = 1);
// Converts <buf> into an <argv>-style vector of strings. If
// <substitute_env_args> is enabled then we'll substitute the
@@ -42,22 +42,22 @@ public:
// The subscript and <argv> operations are not allowed on an
// ACE_ARGV created this way.
- ACE_ARGV (ASYS_TCHAR *argv[],
+ ACE_ARGV (ACE_TCHAR *argv[],
int substitute_env_args = 1);
// Converts <argv> into a linear string. If <substitute_env_args>
// is enabled then we'll substitute the environment variables for
// each $ENV encountered in the string. The <buf> operation is not
// allowed on an ACE_ARGV created this way.
- ACE_ARGV (ASYS_TCHAR *first_argv[],
- ASYS_TCHAR *second_argv[],
+ ACE_ARGV (ACE_TCHAR *first_argv[],
+ ACE_TCHAR *second_argv[],
int substitute_env_args =1);
// Creates an ACE_ARGV which is the concatenation of the first_argv
// and the second argv. The argv arguments should be null pointer
// terminated.
ACE_ARGV (int substitute_env_args = 1);
// Entry point for creating an ASYS_TCHAR *[] command line
// iteratively via the <add> method. When this constructor is used,
// the <ITERATIVE> state is enabled. The <argv> and <buf> methods
// are allowed, and the result is recreated when called multiple
@@ -67,10 +67,10 @@ public:
// Destructor.
// = Accessor arguments.
- const ASYS_TCHAR *operator[] (size_t index);
+ const ACE_TCHAR *operator[] (size_t index);
// Returns the <index>th string in the ARGV array.
- ASYS_TCHAR **argv (void);
+ ACE_TCHAR **argv (void);
// Returns the <argv> array. Caller should not delete this memory
// since the <ARGV> destructor will delete it. If the caller
// modifies the array in the iterative mode, the changes are not
@@ -79,7 +79,7 @@ public:
size_t argc (void) const;
// Returns <argc>.
- const ASYS_TCHAR *buf (void);
+ const ACE_TCHAR *buf (void);
// Returns the <buf>. Caller should not delete this memory since
// the <ARGV> destructor will delete it.
@@ -89,11 +89,11 @@ public:
ACE_ALLOC_HOOK_DECLARE;
// Declare the dynamic allocation hooks.
- int add (const ASYS_TCHAR *next_arg);
+ int add (const ACE_TCHAR *next_arg);
// Add another argument. This only works in the <ITERATIVE> state.
// Returns -1 on failure and 0 on success.
- int add (ASYS_TCHAR *argv[]);
+ int add (ACE_TCHAR *argv[]);
// Add another <argv> array. The <argv> parameter must be NULL
// terminated. This only works in the <ITERATIVE> state. Returns
// -1 on failure and 0 on success.
@@ -105,11 +105,11 @@ public:
enum States
{
TO_STRING = 1,
- // ACE_ARGV converts buf[] to ASYS_TCHAR *argv[]
+ // ACE_ARGV converts buf[] to ACE_TCHAR *argv[]
TO_PTR_ARRAY = 2,
- // ACE_ARGV converts ASYS_TCHAR *argv[] to buf[]
+ // ACE_ARGV converts ACE_TCHAR *argv[] to buf[]
ITERATIVE = 3
// Builds buf[] or ASYS_TCHAR *argv[] iteratively with <add>.
};
private:
@@ -118,9 +118,9 @@ private:
// Creates buf_ from the queue, deletes previous buf_.
int string_to_argv (void);
- // Converts buf_ into the ASYS_TCHAR *argv[] format.
+ // Converts buf_ into the ACE_TCHAR *argv[] format.
- int argv_to_string (ASYS_TCHAR **argv, ASYS_TCHAR *&buf);
+ int argv_to_string (ACE_TCHAR **argv, ACE_TCHAR *&buf);
// Returns the string created from argv in buf and
// returns the number of arguments.
@@ -133,17 +133,17 @@ private:
size_t argc_;
// Number of arguments in the ARGV array.
- ASYS_TCHAR **argv_;
+ ACE_TCHAR **argv_;
// The array of string arguments.
- ASYS_TCHAR *buf_;
+ ACE_TCHAR *buf_;
// Buffer containing the <argv> contents.
size_t length_;
// Total length of the arguments in the queue, not counting
// separating spaces
- ACE_Unbounded_Queue<ASYS_TCHAR *> queue_;
+ ACE_Unbounded_Queue<ACE_TCHAR *> queue_;
// Queue which keeps user supplied arguments. This is only
// active in the "iterative" mode.
};
@@ -42,22 +42,22 @@ public:
// terminated.
ACE_ARGV (int substitute_env_args = 1);
- // Entry point for creating an ASYS_TCHAR *[] command line
+ // Entry point for creating an ACE_TCHAR *[] command line
// iteratively via the <add> method. When this constructor is used,
// the <ITERATIVE> state is enabled. The <argv> and <buf> methods
@@ -105,11 +105,11 @@ public:
ITERATIVE = 3
- // Builds buf[] or ASYS_TCHAR *argv[] iteratively with <add>.
+ // Builds buf[] or ACE_TCHAR *argv[] iteratively with <add>.
};
private: